==> glbinding_2.1.1.orig.tar.gz: glbinding-2.1.1/source/glbinding/source/Binding_objects_l.cpp <==

#include "Binding_pch.h"

using namespace gl;


namespace glbinding
{


Function<void, GLenum, GLuint, GLsizei, const GLchar *> Binding::LabelObjectEXT("glLabelObjectEXT");
Function<void, GLenum, GLint> Binding::LightEnviSGIX("glLightEnviSGIX");
Function<void, GLenum, GLfloat> Binding::LightModelf("glLightModelf");
Function<void, GLenum, const GLfloat *> Binding::LightModelfv("glLightModelfv");
Function<void, GLenum, GLint> Binding::LightModeli("glLightModeli");
Function<void, GLenum, const GLint *> Binding::LightModeliv("glLightModeliv");
Function<void, GLenum, GLfixed> Binding::LightModelxOES("glLightModelxOES");
Function<void, GLenum, const GLfixed *> Binding::LightModelxvOES("glLightModelxvOES");
Function<void, GLenum, GLenum, GLfloat> Binding::Lightf("glLightf");
Function<void, GLenum, GLenum, const GLfloat *> Binding::Lightfv("glLightfv");
Function<void, GLenum, GLenum, GLint> Binding::Lighti("glLighti");
Function<void, GLenum, GLenum, const GLint *> Binding::Lightiv("glLightiv");
Function<void, GLenum, GLenum, GLfixed> Binding::LightxOES("glLightxOES");
Function<void, GLenum, GLenum, const GLfixed *> Binding::LightxvOES("glLightxvOES");
Function<void, GLint, GLushort> Binding::LineStipple("glLineStipple");
Function<void, GLfloat> Binding::LineWidth("glLineWidth");
Function<void, GLfixed> Binding::LineWidthxOES("glLineWidthxOES");
Function<void, GLuint> Binding::LinkProgram("glLinkProgram");
Function<void, GLhandleARB> Binding::LinkProgramARB("glLinkProgramARB");
Function<void, GLuint> Binding::ListBase("glListBase");
Function<void, GLuint, GLuint, const void **, const GLsizei *, const GLuint *, const GLuint *, GLuint> Binding::ListDrawCommandsStatesClientNV("glListDrawCommandsStatesClientNV");
Function<void, GLuint, GLenum, GLfloat> Binding::ListParameterfSGIX("glListParameterfSGIX");
Function<void, GLuint, GLenum, const GLfloat *> Binding::ListParameterfvSGIX("glListParameterfvSGIX");
Function<void, GLuint, GLenum, GLint> Binding::ListParameteriSGIX("glListParameteriSGIX");
Function<void, GLuint, GLenum, const GLint *> Binding::ListParameterivSGIX("glListParameterivSGIX");
Function<void> Binding::LoadIdentity("glLoadIdentity");
Function<void, FfdMaskSGIX> Binding::LoadIdentityDeformationMapSGIX("glLoadIdentityDeformationMapSGIX");
Function<void, const GLdouble *> Binding::LoadMatrixd("glLoadMatrixd");
Function<void, const GLfloat *> Binding::LoadMatrixf("glLoadMatrixf");
Function<void, const GLfixed *> Binding::LoadMatrixxOES("glLoadMatrixxOES");
Function<void, GLuint> Binding::LoadName("glLoadName");
Function<void, GLenum, GLuint, GLsizei, const GLubyte *> Binding::LoadProgramNV("glLoadProgramNV");
Function<void, const GLdouble *> Binding::LoadTransposeMatrixd("glLoadTransposeMatrixd");
Function<void, const GLdouble *> Binding::LoadTransposeMatrixdARB("glLoadTransposeMatrixdARB");
Function<void, const GLfloat *> Binding::LoadTransposeMatrixf("glLoadTransposeMatrixf");
Function<void, const GLfloat *> Binding::LoadTransposeMatrixfARB("glLoadTransposeMatrixfARB");
Function<void, const GLfixed *> Binding::LoadTransposeMatrixxOES("glLoadTransposeMatrixxOES");
Function<void, GLint, GLsizei> Binding::LockArraysEXT("glLockArraysEXT");
Function<void, GLenum> Binding::LogicOp("glLogicOp");


} // namespace glbinding

==> glbinding_3.3.0.orig.tar.gz: glbinding-3.3.0/source/glbinding/source/Binding_objects_l.cpp <==

#include "Binding_pch.h"


using namespace gl;


namespace glbinding
{


Function<void, GLenum, GLuint, GLsizei, const GLchar *> Binding::LabelObjectEXT("glLabelObjectEXT");
Function<void, GLuint, GLbitfield, GLuint, GLenum, GLint, GLint, GLint, GLint, GLuint, GLenum, GLint, GLint, GLint, GLint, GLsizei, GLsizei, GLsizei> Binding::LGPUCopyImageSubDataNVX("glLGPUCopyImageSubDataNVX");
Function<void> Binding::LGPUInterlockNVX("glLGPUInterlockNVX");
Function<void, GLbitfield, GLuint, GLintptr, GLsizeiptr, const void *> Binding::LGPUNamedBufferSubDataNVX("glLGPUNamedBufferSubDataNVX");
Function<void, GLenum, GLint> Binding::LightEnviSGIX("glLightEnviSGIX");
Function<void, GLenum, GLenum, GLfloat> Binding::Lightf("glLightf");
Function<void, GLenum, GLenum, const GLfloat *> Binding::Lightfv("glLightfv");
Function<void, GLenum, GLenum, GLint> Binding::Lighti("glLighti");
Function<void, GLenum, GLenum, const GLint *> Binding::Lightiv("glLightiv");
Function<void, GLenum, GLfloat> Binding::LightModelf("glLightModelf");
Function<void, GLenum, const GLfloat *> Binding::LightModelfv("glLightModelfv");
Function<void, GLenum, GLint> Binding::LightModeli("glLightModeli");
Function<void, GLenum, const GLint *> Binding::LightModeliv("glLightModeliv");
Function<void, GLenum, GLfixed> Binding::LightModelxOES("glLightModelxOES");
Function<void, GLenum, const GLfixed *> Binding::LightModelxvOES("glLightModelxvOES");
Function<void, GLenum, GLenum, GLfixed> Binding::LightxOES("glLightxOES");
Function<void, GLenum, GLenum, const GLfixed *> Binding::LightxvOES("glLightxvOES");
Function<void, GLint, GLushort> Binding::LineStipple("glLineStipple");
Function<void, GLfloat> Binding::LineWidth("glLineWidth");
Function<void, GLfixed> Binding::LineWidthxOES("glLineWidthxOES");
Function<void, GLuint> Binding::LinkProgram("glLinkProgram");
Function<void, GLhandleARB> Binding::LinkProgramARB("glLinkProgramARB");
Function<void, GLuint> Binding::ListBase("glListBase");
Function<void, GLuint, GLuint, const void **, const GLsizei *, const GLuint *, const GLuint *, GLuint> Binding::ListDrawCommandsStatesClientNV("glListDrawCommandsStatesClientNV");
Function<void, GLuint, GLenum, GLfloat> Binding::ListParameterfSGIX("glListParameterfSGIX");
Function<void, GLuint, GLenum, const GLfloat *> Binding::ListParameterfvSGIX("glListParameterfvSGIX");
Function<void, GLuint, GLenum, GLint> Binding::ListParameteriSGIX("glListParameteriSGIX");
Function<void, GLuint, GLenum, const GLint *> Binding::ListParameterivSGIX("glListParameterivSGIX");
Function<void> Binding::LoadIdentity("glLoadIdentity");
Function<void, FfdMaskSGIX> Binding::LoadIdentityDeformationMapSGIX("glLoadIdentityDeformationMapSGIX");
Function<void, const GLdouble *> Binding::LoadMatrixd("glLoadMatrixd");
Function<void, const GLfloat *> Binding::LoadMatrixf("glLoadMatrixf");
Function<void, const GLfixed *> Binding::LoadMatrixxOES("glLoadMatrixxOES");
Function<void, GLuint> Binding::LoadName("glLoadName");
Function<void, GLenum, GLuint, GLsizei, const GLubyte *> Binding::LoadProgramNV("glLoadProgramNV");
Function<void, const GLdouble *> Binding::LoadTransposeMatrixd("glLoadTransposeMatrixd");
Function<void, const GLdouble *> Binding::LoadTransposeMatrixdARB("glLoadTransposeMatrixdARB");
Function<void, const GLfloat *> Binding::LoadTransposeMatrixf("glLoadTransposeMatrixf");
Function<void, const GLfloat *> Binding::LoadTransposeMatrixfARB("glLoadTransposeMatrixfARB");
Function<void, const GLfixed *> Binding::LoadTransposeMatrixxOES("glLoadTransposeMatrixxOES");
Function<void, GLint, GLsizei> Binding::LockArraysEXT("glLockArraysEXT");
Function<void, GLenum> Binding::LogicOp("glLogicOp");


} // namespace glbinding
